@@ -173,40 +173,30 @@ class LatchPersistence(DataPersistence):
         :param str remote_path: remote latch:// path
         :param str local_path: directory to copy to
         """
-        internal_execution_id = _os.environ.get("FLYTE_INTERNAL_EXECUTION_ID")
+        r = _session.post(
+            self._latch_endpoint + "/api/get-presigned-urls-for-dir",
+            json={"object_url": remote_path, "execution_name": _os.environ.get("FLYTE_INTERNAL_EXECUTION_ID")},
+            timeout=90,
+        )
+        if r.status_code != 200:
+            raise FlyteUserException("failed to download `{}`".format(remote_path))
 
-        if internal_execution_id is not None:
-            r = _session.post(
-                self._latch_endpoint + "/api/get-presigned-urls-for-dir",
-                json={"object_url": remote_path, "execution_name": internal_execution_id},
-                timeout=90,
-            )
-            if r.status_code != 200:
-                raise FlyteUserException("failed to download `{}`".format(remote_path))
+        dir_key = self._split_s3_path_to_key(remote_path)[1:]
+        dir_key = _enforce_trailing_slash(dir_key)
+        key_to_url_map = r.json()["key_to_url_map"]
 
-            dir_key = self._split_s3_path_to_key(remote_path)[1:]
-            dir_key = _enforce_trailing_slash(dir_key)
-            key_to_url_map = r.json()["key_to_url_map"]
+        task_tuples = []
+        for key, url in key_to_url_map.items():
+            local_file_path = _os.path.join(local_path, key.replace(dir_key, "", 1))
+            dir = "/".join(local_file_path.split("/")[:-1])
+            _os.makedirs(dir, exist_ok=True)
+            task_tuples.append((url, local_file_path))
 
-            task_tuples = []
-            for key, url in key_to_url_map.items():
-                local_file_path = _os.path.join(local_path, key.replace(dir_key, "", 1))
-                dir = "/".join(local_file_path.split("/")[:-1])
-                _os.makedirs(dir, exist_ok=True)
-                task_tuples.append((url, local_file_path))
-
-            pool = ThreadPool(100)
-            pool.map(get, task_tuples)
-            pool.start()
-            pool.wait_completion()
-            return True
-        else:
-            try:
-                from latch_cli.services.cp import cp
-
-                cp(remote_path, local_path)
-            except Exception as e:
-                raise FlyteUserException("failed to get presigned urls for `{}`".format(remote_path)) from e
+        pool = ThreadPool(100)
+        pool.map(get, task_tuples)
+        pool.start()
+        pool.wait_completion()
+        return True
 
     def download(self, remote_path: str, local_path: str) -> bool:
         """
