@@ -8,7 +8,7 @@ from dataclasses import dataclass, field
 from dataclasses_json import config, dataclass_json
 from marshmallow import fields
 
-from flytekit.core.context_manager import FlyteContext
+from flytekit.core.context_manager import ExecutionState, FlyteContext
 from flytekit.core.type_engine import TypeEngine, TypeTransformer, TypeTransformerFailedError
 from flytekit.loggers import logger
 from flytekit.models.core.types import BlobType
@@ -318,12 +318,20 @@ class FlyteFilePathTransformer(TypeTransformer[FlyteFile]):
         else:
             raise TypeTransformerFailedError(f"Expected FlyteFile or os.PathLike object, received {type(python_val)}")
 
+        # Don't upload by default in local execution
+        if remote_path is None and ctx.execution_state.mode == ExecutionState.Mode.LOCAL_WORKFLOW_EXECUTION:
+            should_upload = False
+
         # If we're uploading something, that means that the uri should always point to the upload destination.
         if should_upload:
             if remote_path is None:
                 remote_path = ctx.file_access.get_random_remote_path(source_path)
-            ctx.file_access.put_data(source_path, remote_path, is_multipart=False)
-            return Literal(scalar=Scalar(blob=Blob(metadata=meta, uri=remote_path)))
+
+            put_res = ctx.file_access.put_data(source_path, remote_path, is_multipart=False)
+            if put_res is None:
+                put_res = {}
+
+            return Literal(scalar=Scalar(blob=Blob(metadata=meta, uri=remote_path)), hash=put_res.get("cache"))
         # If not uploading, then we can only take the original source path as the uri.
         else:
             return Literal(scalar=Scalar(blob=Blob(metadata=meta, uri=source_path)))
